@@ -1,16 +1,17 @@
-import subprocess
-import os
-import sys
-import importlib
-from pathlib import Path
-import requests
-import shutil
-import tempfile
-import typer
-from urllib import request
 import json
-from pathlib import PurePath
-import warnings
+import os
+import shutil
+import subprocess
+import sys
+import tempfile
+from pathlib import Path, PurePath
+from typing import Union
+from urllib import request
+
+import requests
+import typer
+
+from .file_patterns import PkgFileFilter
 from .filter_env import filter_env
 
 EMSDK_VER = "latest"
@@ -18,20 +19,25 @@ EMSDK_VER = "latest"
 HERE = Path(__file__).parent
 
 
-def shrink_conda_meta(prefix):
-    conda_meta = os.path.join(prefix, "conda-meta")
+def shrink_conda_meta(prefix, target_dir=None):
+    if not target_dir:
+        target_dir = Path(prefix)
 
-    for filename in os.listdir(conda_meta):
-        f = os.path.join(conda_meta, filename)
-        if os.path.isfile(f) and f.endswith(".json"):
-            with open(f, "r") as file:
-                data = json.load(file)
+    prefix = Path(prefix)
 
-                data.pop("paths_data", None)
-                data.pop("files", None)
+    conda_meta = prefix / "conda-meta"
+    target_dir = Path(target_dir) / "conda-meta"
+    target_dir.mkdir(parents=True, exist_ok=True)
 
-            with open(f, "w") as outfile:
-                json.dump(data, outfile)
+    for p in conda_meta.glob("*.json"):
+        with open(p, "r") as file:
+            data = json.load(file)
+
+            data.pop("paths_data", None)
+            data.pop("files", None)
+
+        with open(target_dir / p.name, "w") as outfile:
+            json.dump(data, outfile)
 
 
 def download_and_setup_emsdk(emsdk_version):
@@ -105,7 +111,7 @@ def get_file_packager_path():
     file_packager_path = os.environ.get("FILE_PACKAGER")
     if file_packager_path is None:
         print(
-            f"FILE_PACKAGER needs to be an env variable pointing to emscpriptens file_packager.py"
+            "FILE_PACKAGER needs to be an env variable pointing to emscpriptens file_packager.py"
         )
         raise typer.Exit()
     return file_packager_path
@@ -131,9 +137,9 @@ def emscripten_file_packager(
 
     cmd = [
         sys.executable,
-        file_packager_path,
+        str(file_packager_path),
         f"{outname}.data",
-        f"--preload",
+        "--preload",
         f"{to_mount}@{mount_path}",
         f"--js-output={outname}.js",
         f"--export-name={export_name}",
@@ -146,26 +152,36 @@ def emscripten_file_packager(
 
     if lz4:
         cmd += ["--lz4"]
-    if not silent:
-        subprocess.run(cmd, shell=False, check=True, cwd=cwd)
-    else:
-        subprocess.run(
-            cmd,
-            shell=False,
-            check=True,
-            cwd=cwd,
-            stderr=subprocess.DEVNULL,
-            stdout=subprocess.DEVNULL,
-        )
+    try:
+        if not silent:
+            res = subprocess.check_output(
+                cmd, shell=False, cwd=cwd, stderr=subprocess.STDOUT
+            )
+            print(res.decode("utf-8"))
+        else:
+            subprocess.run(
+                cmd,
+                shell=False,
+                check=True,
+                cwd=cwd,
+                stderr=subprocess.DEVNULL,
+                stdout=subprocess.DEVNULL,
+            )
+    except subprocess.CalledProcessError as e:
+        print(e.output.decode("utf-8"))
+        raise e
 
 
 def pack_environment(
-    env_prefix: Path, outname, export_name, pack_outdir=None, download_emsdk=None
+    env_prefix: Path,
+    outname: str,
+    export_name: str,
+    pkg_file_filter: PkgFileFilter,
+    pack_outdir: Union[str, None] = None,
+    download_emsdk: Union[str, None] = None,
 ):
     # name of the env
     env_name = PurePath(env_prefix).parts[-1]
-    env_root = os.path.join(*PurePath(env_prefix).parts[:-1])
-
 
     # create a temp dir and store the filter&copy
     # the data to the tmp directory
@@ -173,7 +189,12 @@ def pack_environment(
         target_dir = os.path.join(temp_dir, env_name)
         os.makedirs(target_dir)
 
-        filter_env(env_prefix=env_prefix, target_dir=target_dir)
+        filter_env(
+            env_prefix=env_prefix,
+            target_dir=target_dir,
+            pkg_file_filter=pkg_file_filter,
+        )
+        shrink_conda_meta(env_prefix, target_dir=target_dir)
 
         emscripten_file_packager(
             outname=outname,
@@ -186,32 +207,21 @@ def pack_environment(
             cwd=str(temp_dir),
             download_emsdk=download_emsdk,
         )
+
         if pack_outdir is None:
             pack_outdir = os.getcwd()
+
         shutil.copy(os.path.join(str(temp_dir), f"{outname}.data"), pack_outdir)
         shutil.copy(os.path.join(str(temp_dir), f"{outname}.js"), pack_outdir)
 
 
-def pack_python_core(env_prefix: Path, outname, version, export_name, download_emsdk):
-    warnings.warn(
-        "pack_python_core is deprecated, use `pack_environment`",
-        DeprecationWarning,
-    )
-    pack_environment(
-        env_prefix=env_prefix,
-        outname=outname,
-        export_name=export_name,
-        download_emsdk=download_emsdk,
-    )
-
-
 def pack_file(
     file: Path,
-    mount_path,
+    mount_path: str,
     outname: str,
-    export_name,
-    use_preload_plugins=True,
-    silent=False,
+    export_name: str,
+    use_preload_plugins: bool = True,
+    silent: bool = False,
 ):
 
     with tempfile.TemporaryDirectory() as temp_dir:
@@ -222,7 +232,7 @@ def pack_file(
 
         emscripten_file_packager(
             outname=outname,
-            to_mount=f"assets/",
+            to_mount="assets/",
             mount_path=mount_path,
             export_name=export_name,
             use_preload_plugins=use_preload_plugins,
@@ -236,8 +246,7 @@ def pack_file(
         shutil.copy(os.path.join(temp_dir_str, f"{outname}.js"), os.getcwd())
 
 
-def create_env(pkg_name, prefix, platform):
-    # cmd = ['$MAMBA_EXE' ,'create','--prefix', prefix,'--platform=emscripten-32'] + [pkg_name] #+ ['--dryrun']
+def create_env(pkg_name: str, prefix: str, platform: str):
     cmd = [
         f"$MAMBA_EXE create --yes --prefix {prefix} --platform={platform} --no-deps {pkg_name}"
     ]
@@ -248,31 +257,22 @@ def create_env(pkg_name, prefix, platform):
     assert returncode == 0
 
 
-def make_pkg_name(recipe):
-
-    name = recipe["package"]["name"]
-    version = recipe["package"]["version"].replace(".", "_")
-    build_number = recipe["build"].get("number", 0)
-
-    return f"{name}_v_{version}__bn_{build_number}"
-
-
-def pack_conda_pkg(recipe, pack_prefix, pack_outdir, outname):
+def pack_conda_pkg(recipe, pack_prefix, pack_outdir, outname, pkg_file_filter):
     """pack a conda pkg with emscriptens filepackager
 
     Args:
         recipe (dict): the rendered recipe as dict
-        pack_prefix (str): path where the packed env will be created (WARNING this will override the envs content)
+        pack_prefix (str): path where the packed env will be created
+                           (WARNING this will override the envs content)
         pack_outdir (str): destination folder for the created pkgs
     """
     pkg_name = recipe["package"]["name"]
-    print("pack_prefix", pack_prefix)
     create_env(pkg_name, pack_prefix, platform="emscripten-32")
-    # shrink_conda_meta(pack_prefix)
 
     pack_environment(
         env_prefix=pack_prefix,
         outname=outname,
         export_name="globalThis.Module",
+        pkg_file_filter=pkg_file_filter,
         pack_outdir=pack_outdir,
     )
