@@ -1,11 +1,9 @@
-from enum import Enum
-from pydantic import BaseModel, Field
-from typing import Union, List
-from pydantic import BaseModel, validator, PrivateAttr, Field, Extra
 import fnmatch
-
-import pathlib
 import re
+from typing import Dict, List, Union
+
+import yaml
+from pydantic import BaseModel, Extra, Field, PrivateAttr
 
 
 class FilePatternsModelBase(BaseModel, extra=Extra.forbid):
@@ -55,3 +53,20 @@ class FileFilter(BaseModel, extra=Extra.forbid):
                     return False
 
         return include
+
+
+class PkgFileFilter(BaseModel, extra=Extra.forbid):
+    packages: Dict[str, FileFilter]
+    default: FileFilter
+
+    def match(self, pkg_name, path):
+        matcher = self.packages.get(pkg_name, self.default)
+        return matcher.match(path)
+
+
+def pkg_file_filter_from_yaml(path):
+
+    with open(path, "r") as pack_config_file:
+        pack_config = yaml.safe_load(pack_config_file)
+        pkg_file_filter = PkgFileFilter.parse_obj(pack_config)
+    return pkg_file_filter
